#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/install.sh - eibd installation
#
# Creation   :  2015-08-15 Tom Schulz, tom_strike(at)gmx(dot)de
# Last Update:  2018-02-10 Tom Schulz
#
# Copyright (c) 2015-08-15 Tom Schulz, tom_strike(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set package name
packageName=eibd

package_menu_item='Eibd'

# ----------------------------------------------------------------------------
# Add menu
# ----------------------------------------------------------------------------
/var/install/bin/add-menu setup.services.menu setup.services.${packageName}.menu "${package_menu_item}"

# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------

if [ -f "/etc/config.d/${packageName}" ]
then
    update=true
fi

/var/install/config.d/${packageName}-update.sh

# ----------------------------------------------------------------------------
# Create user and group
# ----------------------------------------------------------------------------

_uid_gid=${packageName}

__group=$( getent group ${_uid_gid} )

if [ -z "${__group}" ]
then
    /var/install/bin/add-group ${_uid_gid} 75 >/dev/null
fi

__user=$( getent passwd ${_uid_gid} )

if [ -z "${__user}" ]
then
    /var/install/bin/add-user ${_uid_gid} '*' 75 75 "System User for $packageName" \
    /var/lib/${packageName} '' >/dev/null
fi

# ----------------------------------------------------------------------------
# Add user to additional group dialout
# ----------------------------------------------------------------------------

/var/install/bin/add-user-to-additional-group -u ${packageName} -g dialout

# ----------------------------------------------------------------------------
# Invalidate password of user
# ----------------------------------------------------------------------------

usermod -L $_uid_gid

# ----------------------------------------------------------------------------
# Create device for CDC ACM
# ----------------------------------------------------------------------------

# Obsolete due to implemetation of udev

# if [ ! -e /dev/ttyACM0 ]; then 
#     /bin/mknod /dev/ttyACM0 c 166 0
#     /bin/chown -c eibd /dev/ttyACM0
# fi

# ----------------------------------------------------------------------------
# Create kill script
# ----------------------------------------------------------------------------

package_pos=73
package_kill='K'`/usr/bin/expr 100 - $package_pos`${packageName}
ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_kill}

# ----------------------------------------------------------------------------
# Start configuration
# ----------------------------------------------------------------------------

if ${update:-false}
then
    /var/install/config.d/${packageName}.sh --quiet
    . /etc/config.d/${packageName}
    if [ "${START_EIBD}" = "yes" ]
    then
        /etc/init.d/${packageName} start
    fi
fi

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
