#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/eibd-update.sh - paramater update script
#
# Creation   :  2015-08-15 Tom Schulz, tom_strike(at)gmx(dot)de
# Last Update:  2015-09-14 Tom Schulz
#
# Copyright (c) 2015-08-15 Tom Schulz, tom_strike(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=eibd

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_EIBD='no'
EIBD_INTERFACE='ipt'
EIBD_INTERFACE_ADDRESS='127.0.0.1'
EIBD_GROUP_CACHE='no'
EIBD_DAEMON='yes'
EIBD_DISCOVERY='yes'
EIBD_ERROR_LEVEL=''
EIBD_ROUTING='no'
EIBD_SERVER='yes'
EIBD_TRACE_LEVEL=''
EIBD_TUNNELING='yes'
EIBD_SET_EIB_ADDR='no'
EIBD_EIB_ADDR='0.0.1'
EIBD_LISTEN_TCP='yes'
EIBD_LISTEN_TCP_PORT='6720'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
         /var/install/bin/backup-file --quiet ${packageName}
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "2015-08-25" "Tom Schulz"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_EIBD" "Start EIBD? Use: yes or no"
    printvar "EIBD_INTERFACE" "Type of interface for EIBD"
    printvar "EIBD_INTERFACE_ADDRESS" "IP-Address"
    printvar "EIBD_GROUP_CACHE" "Enable caching of group communication network state"
    printvar "EIBD_DAEMON" "Start the programm as daemon, the output will be written to FILE, if the argument present"
    printvar "EIBD_DISCOVERY" "enable the EIBnet/IP server to answer discovery and description requests (SEARCH, DESCRIPTION)"
    printvar "EIBD_ROUTING" "Enable EIBnet/IP Routing in the EIBnet/IP server"
    printvar "EIBD_SERVER" "Starts the EIBnet/IP server part"
    printvar "EIBD_TUNNELING" "Enable EIBnet/IP Tunneling in the EIBnet/IP server"
    printvar "EIBD_SET_EIB_ADDR" "Set EIB Address? Use: yes or no"
    printvar "EIBD_EIB_ADDR" "Set your own EIB-address to EIBADDR (default: 0.0.1), for drivers, which need an address"
    printvar "EIBD_LISTEN_TCP" "Listen at TCP-PORT? Use: yes or no"
    printvar "EIBD_LISTEN_TCP_PORT" "Listen PORT (default 6720)"

    # ------------------------------------------------------------------------
    printgroup "Advanced configuration"
    # ------------------------------------------------------------------------
    printvar "EIBD_ERROR_LEVEL" "Set error level"
    printvar "EIBD_TRACE_LEVEL" "Set trace level"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{

# create file check.d

    printgpl -check ${packageName} '2015-08-15' 'Tom Schulz' >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG

# Variable                OPT_VARIABLE      VARIABLE_N          VALUE
START_EIBD                -                 -                   YESNO
EIBD_INTERFACE            START_EIBD        -                   EIBD_INTERFACE_TYPE
EIBD_INTERFACE_ADDRESS    START_EIBD        -                   EIBD_INTERFACE_ADDRESS_TYPE
EIBD_GROUP_CACHE          START_EIBD        -                   YESNO
EIBD_DAEMON               START_EIBD        -                   YESNO
EIBD_DISCOVERY            START_EIBD        -                   YESNO
EIBD_ERROR_LEVEL          START_EIBD        -                   ENUMERIC
EIBD_ROUTING              START_EIBD        -                   YESNO
EIBD_SERVER               START_EIBD        -                   YESNO
EIBD_TRACE_LEVEL          START_EIBD        -                   EIBD_TRACE_LEVEL_TYPE
EIBD_TUNNELING            START_EIBD        -                   YESNO
EIBD_SET_EIB_ADDR         START_EIBD        -                   YESNO
EIBD_EIB_ADDR             EIBD_SET_EIB_ADDR -                   EIBD_EIB_ADDR_TYPE
EIBD_LISTEN_TCP           START_EIBD        -                   YESNO
EIBD_LISTEN_TCP_PORT      EIBD_LISTEN_TCP   -                   EIBD_LISTEN_TCP_PORT_TYPE

EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/${packageName}
chown root /etc/check.d/${packageName}

printgpl --check_exp ${packageName} '2015-08-15' 'Tom Schulz' >/etc/check.d/${packageName}.exp
cat >> /etc/check.d/${packageName}.exp <<EOFG

EIBD_INTERFACE_TYPE         = 'ip|ipt|iptn|tpuarts|usb'
                            : 'only ip, ipt, iptn, tpuarts, usb are allowed'

EIBD_INTERFACE_ADDRESS_TYPE = '(RE:IPADDR)|(RE:NUMERIC).(RE:NUMERIC).(RE:NUMERIC)|(RE:ABS_PATH)'
                            : 'only ip-, hardware-address or device-name allowed'

EIBD_EIB_ADDR_TYPE          = '()|(RE:NUMERIC).(RE:NUMERIC).(RE:NUMERIC)'
                            : 'should be KNX-address e.g. 0.0.1 (default)'

EIBD_TRACE_LEVEL_TYPE       = '()|(RE:PORT)'
                            : 'empty or value between 1 and 65535'

EIBD_LISTEN_TCP_PORT_TYPE   = '()|(RE:PORT)'
                            : 'empty or port between 1 and 65535'

EOFG

# Set rights for check.exp file
chmod 0600 /etc/check.d/${packageName}.exp
chown root /etc/check.d/${packageName}.exp

# printgpl --check_ext ${packageName} '2015-08-26' 'Tom Schulz' >/etc/check.d/${packageName}.ext
# cat >> /etc/check.d/${packageName}.ext <<EOFG
#
# EOFG

# Set rights for check.ext file
# chmod 0600 /etc/check.d/${packageName}.ext
# chown root /etc/check.d/${packageName}.ext
# create file check.ext - not used yet

}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file

makeConfigFile /etc/default.d/${packageName}

# Update from old version
renameOldVariables

# Write new config file
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
makeCheckFile

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
